cadl.deprecated package
=======================

Submodules
----------

cadl.deprecated.seq2seq module
------------------------------

.. automodule:: cadl.deprecated.seq2seq
    :members:
    :undoc-members:
    :show-inheritance:

cadl.deprecated.seq2seq_model module
------------------------------------

.. automodule:: cadl.deprecated.seq2seq_model
    :members:
    :undoc-members:
    :show-inheritance:

cadl.deprecated.seq2seq_utils module
------------------------------------

.. automodule:: cadl.deprecated.seq2seq_utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cadl.deprecated
    :members:
    :undoc-members:
    :show-inheritance:
